@@ -66,7 +66,7 @@ class KdeSudo : QObject {
 		/*
 		* This slot gets exectuted when sudo exits
 		*/
-		void procExited();
+		void procExited(int exitCode);
 	
 		/*
 		* This slot overrides the slot from KPasswordDialog
