@@ -8,6 +8,7 @@
                                        Anthony Mercatante <tonio@kubuntu.org>
                                        Canonical Ltd (Jonathan Riddell 
                                                       <jriddell@ubuntu.com>)
+                           (C) 2009 by Harald Sitter <apachelogger@ubuntu.com>
 
  ***************************************************************************/
 
@@ -39,7 +40,7 @@ int main(int argc, char **argv)
 {
 	KAboutData about(
 		"kdesudo", 0, ki18n("KdeSudo"),
-		"3.1", ki18n("Sudo frontend for KDE"),
+		"3.4.2.2", ki18n("Sudo frontend for KDE"),
 		KAboutData::License_GPL,
 		ki18n("(C) 2007 - 2008 Anthony Mercatante"),
 		KLocalizedString(),
@@ -55,6 +56,8 @@ int main(int argc, char **argv)
 		"martin.bohm@kubuntu.org");
 	about.addAuthor(ki18n("Jonathan Riddell"), KLocalizedString(),
 		"jriddell@ubuntu.com");
+	about.addAuthor(ki18n("Harald Sitter"), KLocalizedString(),
+		"apachelogger@ubuntu.com");
 
 	KCmdLineArgs::init(argc, argv, &about);
 
@@ -76,33 +79,28 @@ int main(int argc, char **argv)
                                                "displayed in the dialog"));
 	options.add("noignorebutton", ki18n("Do not display « ignore » button"));
 	options.add("attach <winid>", ki18n("Makes the dialog transient for an X app specified by winid"));
+	options.add("desktop <desktop file>", ki18n("Manual override for "
+                                           "automatic desktop file detection"));
 
 	options.add("+command", ki18n("The command to execute"));
+	
 	KCmdLineArgs::addCmdLineOptions( options );
-
 	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
 	KApplication a;
 
-	QString executable;
-	QStringList executableList;
-	QString arg;
-	QString command;
-	QStringList commandlist;
-	QString icon;
+	QString executable, arg, command, icon;
+	QStringList executableList, commandlist;
+	KDesktopFile *desktopFile;
 
 	if (args->isSet("c"))
 		executable = args->getOption("c");
 
-
-	if (args->count())
+	if (args->count() && executable.isEmpty())
 	{
-		if (executable.isEmpty())
-		{
-			command = args->arg(0);
-			commandlist = command.split(" ");
-			executable = commandlist[0];
-		}
+		command = args->arg(0);
+		commandlist = command.split(" ");
+		executable = commandlist[0];
 	}
 
 	/* We have to make sure the executable is only the binary name */
@@ -110,8 +108,7 @@ int main(int argc, char **argv)
 	executable = executableList[0];
 
 	executableList = executable.split("/");
-	int i = executableList.count() - 1;
-	executable = executableList[i];
+	executable = executableList[executableList.count() - 1];
 
 	/* Kubuntu has a bug in it - this is a workaround for it */  
 	KGlobal::dirs()->addResourceDir("apps","/usr/share/applications/kde");
@@ -128,23 +125,24 @@ int main(int argc, char **argv)
 		executable.remove(pathList[i]);
 	}
 
-	QString deskFilePath = KGlobal::dirs()->findResource("apps", executable + ".desktop");
-
-	KDesktopFile desktopFile(deskFilePath);
+	if (args->isSet("desktop"))
+		desktopFile = new KDesktopFile(args->getOption("desktop"));
+	else
+		desktopFile = new KDesktopFile(executable + ".desktop");
 
 	/* icon parsing */
 	if (args->isSet("i"))
 		icon = args->getOption("i");
 	else
 	{
-		QString iconName = desktopFile.readIcon();
+		QString iconName = desktopFile->readIcon();
 		KIconLoader *loader = KIconLoader::global();
 		icon = loader->iconPath(iconName, -1 * KIconLoader::StdSizes(
 			KIconLoader::SizeHuge), true);
 	}
 
 	/* generic name parsing */
-	QString name = desktopFile.readName();
+	QString name = desktopFile->readName();
 
 	a.setQuitOnLastWindowClosed( false );
 	KdeSudo kdesudo(icon,name);
